@@ -22,7 +22,6 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
-#include <Lum/AppInfo.h>
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
@@ -44,7 +43,7 @@
 
 #include <iostream>
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class MainDialog : public Lum::Dialog
 {
